==> gtk-gnutella_0.96.1.orig.tar.gz: gtk-gnutella-0.96.1/src/core/oob.h <==
/*
 * $Id: oob.h,v 1.3 2005/06/25 01:37:40 daichik Exp $
 *
 * Copyright (c) 2004, Raphael Manfredi
 *
 *----------------------------------------------------------------------
 * This file is part of gtk-gnutella.
 *
 *  gtk-gnutella is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  gtk-gnutella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gtk-gnutella; if not, write to the Free Software
 *  Foundation, Inc.:
 *      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------
 */

/**
 * @ingroup core
 * @file
 *
 * Out-of-band query hit management.
 *
 * @author Raphael Manfredi
 * @date 2004
 */

#ifndef _core_oob_h_
#define _core_oob_h_

#include <glib.h>

/*
 * Public interface.
 */

struct gnutella_node;

void oob_init(void);
void oob_shutdown(void);
void oob_close(void);

void oob_got_results(
	struct gnutella_node *n, GSList *files, gint count, gboolean use_ggep_h);
void oob_deliver_hits(struct gnutella_node *n, gchar *muid, guint8 wanted);

#endif /* _core_oob_h_ */

/* vi: set ts=4: */

==> gtk-gnutella_0.96.3.orig.tar.gz: gtk-gnutella-0.96.3/src/core/oob.h <==
/*
 * $Id: oob.h 12147 2006-10-27 19:55:09Z cbiere $
 *
 * Copyright (c) 2004, Raphael Manfredi
 *
 *----------------------------------------------------------------------
 * This file is part of gtk-gnutella.
 *
 *  gtk-gnutella is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  gtk-gnutella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gtk-gnutella; if not, write to the Free Software
 *  Foundation, Inc.:
 *      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------
 */

/**
 * @ingroup core
 * @file
 *
 * Out-of-band query hit management.
 *
 * @author Raphael Manfredi
 * @date 2004
 */

#ifndef _core_oob_h_
#define _core_oob_h_

#include <glib.h>

/*
 * Public interface.
 */

struct gnutella_node;

void oob_init(void);
void oob_shutdown(void);
void oob_close(void);

void oob_got_results(
	struct gnutella_node *n, GSList *files, gint count, gboolean use_ggep_h);
void oob_deliver_hits(struct gnutella_node *n,
	const gchar *muid, guint8 wanted);

#endif /* _core_oob_h_ */

/* vi: set ts=4: */
